==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/NCursesFrontend.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.2 $
 * $Date: 2004/07/28 17:24:08 $
 *
 */

#ifndef NCURSES_FRONTEND_H
#define NCURSES_FRONTEND_H

#include <deque>
#include <pthread.h>
#include <time.h>

#include <ncurses.h>

#include "Thread.h"
#include "Frontend.h"

class NCursesFrontend : public Frontend
{
	enum EMessageType
	{
		eInfo,
		eWarning,
		eError,
		eDebug
	};

	enum EInputMode
	{
		eNormal,
		eEditQueue,
		eDownloadRate
	};
	
	struct SMessage
	{
		char*		m_szMessage;
		EMessageType	m_eType;
	};

	std::deque< SMessage >	m_Messages;
	int				m_iLineNr;
	bool			m_bUseColor;

	int				m_iNrRows;
	int				m_iNrColumns;
	uint				m_iSelectedQueueEntry;

	// Inputting numbres
	int				m_iInputNumberIndex;
	int				m_iInputValue;

	WINDOW*			m_pWindow;
	EInputMode		m_eInputMode;
 public:
    				NCursesFrontend();
	virtual			~NCursesFrontend();
	virtual void 	frontendError(char* msg);
	virtual void 	frontendWarn(char* msg);
	virtual void 	frontendDebug(char* msg);
	virtual void 	frontendInfo(char* msg);
	virtual void	frontendQueueListEntry( const char* szEntry ) {}; // Override - functionality handled elsewhere
	virtual void 	printStatus();
	virtual void	printMessages();
	virtual float	GetSleepTime() { return 100 * 1000; }
	virtual void	OnDownloadCompleted( const char* szFileName );

private:
	void			PushOnMessageList( const char* szString, EMessageType eType );
	void			PrintQueue();
	void			PrintMessage( SMessage& Msg, int iRow );
	void			PrintKeyInputBar();
	void			PlotHeader( const char* szString, int iRow, int iColorPair );
	void			PlotLine( const char* szString, int iRow, int iColorPair );
	void			ClearRow( int iRow );
	void			UpdateInput();
};

#endif

==> nzbget-0.2.2.tar.gz: nzbget-0.2.2/NCursesFrontend.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.7 $
 * $Date: 2005/07/12 09:37:48 $
 *
 */

#ifndef NCURSES_FRONTEND_H
#define NCURSES_FRONTEND_H

#include <deque>
#include <pthread.h>
#include <time.h>

#include <ncurses.h>

#include "Thread.h"
#include "Frontend.h"

class NCursesFrontend : public Frontend
{
	enum EMessageType
	{
		eInfo,
		eWarning,
		eError,
		eDebug
	};

	enum EInputMode
	{
		eNormal,
		eEditQueue,
		eDownloadRate
	};
	
	struct SMessage
	{
		char*		m_szMessage;
		EMessageType	m_eType;
	};

	std::deque< SMessage >	m_Messages;
	int				m_iLineNr;
	bool			m_bUseColor;

	int				m_iNrRows;
	int				m_iNrColumns;
	uint			m_iSelectedQueueEntry;

	// Inputting numbres
	int				m_iInputNumberIndex;
	int				m_iInputValue;

	WINDOW*			m_pWindow;
	EInputMode		m_eInputMode;
 public:
    				NCursesFrontend();
	virtual			~NCursesFrontend();
	virtual void 	FrontendError(char* msg);
	virtual void 	FrontendWarn(char* msg);
	virtual void 	FrontendDebug(char* msg);
	virtual void 	FrontendInfo(char* msg);
	virtual void	FrontendQueueListEntry( const char* szEntry ) {}; // Override - functionality handled elsewhere
	virtual void 	PrintStatus();
	virtual void	PrintMessages();
	virtual int		GetSleepTime() { return 100 * 1000; }
	virtual void	OnDownloadCompleted( const char* szFileName );

private:
	void			PushOnMessageList( const char* szString, EMessageType eType );
	void			PrintQueue();
	void			PrintMessage( SMessage& Msg, int iRow );
	void			PrintKeyInputBar();
	void			PlotHeader( const char* szString, int iRow, int iColorPair );
	void			PlotLine( const char* szString, int iRow, int iColorPair );
	void			ClearRow( int iRow );
	void			UpdateInput();
};

#endif
